@@ -37,7 +37,7 @@ Authors email : jonas.frantz@helsinki.fi
 #include "gperiodic.h"
 #include "table_data.h"
 
-#define VERSION "2.0.8"
+#define VERSION "2.0.9"
 
 #define PACKAGE "gperiodic"
 #define GPERIODIC_LOCALE_DIR "/usr/share/locale"
@@ -185,7 +185,9 @@ GCallback menu_help_about(void)
 		  "\tAmbrogio.Oliva@sanofi-synthelabo.fr\n"
 		  "\tf.natter@ndh.net\n"
 		  "\tmike@lic145.kiev.ua\n"
-		  "\talipiec@elka.pw.edu.pl";
+		  "\talipiec@elka.pw.edu.pl\n"
+                  "\tdaniel.leidert@wgdd.de\n"
+                  "\tleandro.regueiro@gmail.com";
 
   char *info = _("%s<u>Authors:</u>\n%s\n\n"
 		 "This program shows the periodic table of elements\n"
@@ -313,7 +315,6 @@ void main_prog(void)
 	"    <menu action='FileMenu'>"
 	"      <menuitem action='Exit'/>"
 	"    </menu>"
-	"    <separator action='justify-left'/>"
 	"    <menu action='HelpMenu'>"
 	"      <menuitem action='About'/>"
 	"    </menu>"
@@ -446,7 +447,7 @@ void main_prog(void)
 
 
 int main(int argc, char** argv) {
-  char ch;
+  signed char ch;
 
     textdomain (PACKAGE);
     bindtextdomain(PACKAGE, GPERIODIC_LOCALE_DIR);
